==> ejc-bidprice-api-3.0.0-20230209.114903-15-sources.jar: com/ejianc/business/bidprice/common/vo/InquiryCommonVO.java <==
package com.ejianc.business.bidprice.common.vo;

import com.ejianc.business.bidprice.material.vo.MaterialInquiryPurchaseDetailVO;
import com.ejianc.business.bidprice.material.vo.MaterialInquiryRentDetailVO;
import com.ejianc.business.bidprice.material.vo.MaterialInquirySupplierVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 材料询价
 *
 * @author generator
 *
 */
@ApiModel("询价公共VO")
public class InquiryCommonVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    @ApiModelProperty("单据状态")
    private Integer billState;
    @ApiModelProperty("单据编码")
    private String billCode;
    @ApiModelProperty("项目id")
    private Long projectId;
    @ApiModelProperty("项目名称")
    private String projectName;
    @ApiModelProperty("组织id")
    private Long orgId;
    @ApiModelProperty("组织")
    private String orgName;
    @ApiModelProperty("项目部所属组织id")
    private Long parentOrgId;
    @ApiModelProperty("项目部所属组织")
    private String parentOrgName;
    @ApiModelProperty("采购主题")
    private String purchaseSubject;
    @ApiModelProperty("采购方式：1-项目自采；2-集中采购")
    private Integer purchaseType;
    @ApiModelProperty("采购方式名称")
    private String purchaseTypeName;
    @ApiModelProperty("计价方式：1-采购；2-租赁")
    private Integer pricingType;
    @ApiModelProperty("计价方式名称")
    private Integer pricingTypeName;
    @ApiModelProperty("报价权限：1-指定供应商；2-所有供应商")
    private Integer quotationAuthority;
    @ApiModelProperty("报价权限名称")
    private Integer quotationAuthorityName;
    @ApiModelProperty("查看权限：1-指定供应商：2-所有供应商登录后查看；3-所有供应商免登录查看")
    private Integer viewAuthority;
    @ApiModelProperty("查看权限名称")
    private Integer viewAuthorityName;
    @ApiModelProperty("询价金额")
    private BigDecimal inquiryMny;
    @ApiModelProperty("计划使用日期")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date planUseDate;
    @ApiModelProperty("经办人id")
    private Long employeeId;
    @ApiModelProperty("经办人")
    private String employeeName;
    @ApiModelProperty("经办人部门id")
    private Long departmentId;
    @ApiModelProperty("经办人部门")
    private String departmentName;
    @ApiModelProperty("询价日期")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date inquiryDate;
    @ApiModelProperty("联系人")
    private Long contactsId;
    @ApiModelProperty("联系人姓名")
    private String contactsName;
    @ApiModelProperty("联系电话")
    private String phone;
    @ApiModelProperty("报价截止日期")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm", timezone = "GMT+8")
    private Date quoteEndDate;
    @ApiModelProperty("发票要求")
    private String invoiceRequirement;
    @ApiModelProperty("付款方式")
    private String paymentMethod;
    @ApiModelProperty("询价说明")
    private String memo;
    @ApiModelProperty("询价状态：1-未开始；2-报价中；3-已截止；4-已中标")
    private Integer inquiryState;
    @ApiModelProperty("询价状态")
    private String inquiryStateName;

    @ApiModelProperty("材料询价-采购清单")
    private List<MaterialInquiryPurchaseDetailVO> materialInquiryPurchaseDetailList = new ArrayList<>();
    @ApiModelProperty("材料询价-租赁清单")
    private List<MaterialInquiryRentDetailVO> materialInquiryRentDetailList = new ArrayList<>();
    @ApiModelProperty("材料询价-候选供应商")
    private List<MaterialInquirySupplierVO> materialInquirySupplierList = new ArrayList<>();

    @ApiModelProperty("单据状态名称")
    private String billStateName;

    /**
     * 单据状态
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    /**
     * 单据编码
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    /**
     * 项目id
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    /**
     * 组织id
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织id
     */
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    /**
     * 组织id
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织id
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    /**
     * 项目部所属组织id
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getParentOrgId() {
        return parentOrgId;
    }

    /**
     * 项目部所属组织id
     */
    @ReferDeserialTransfer
    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    /**
     * 项目部所属组织
     */
    public String getParentOrgName() {
        return parentOrgName;
    }

    /**
     * 项目部所属组织
     */
    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    /**
     * 采购主题
     */
    public String getPurchaseSubject() {
        return purchaseSubject;
    }

    /**
     * 采购主题
     */
    public void setPurchaseSubject(String purchaseSubject) {
        this.purchaseSubject = purchaseSubject;
    }

    /**
     * 采购方式：1-项目自采；2-集中采购
     */
    public Integer getPurchaseType() {
        return purchaseType;
    }

    /**
     * 采购方式：1-项目自采；2-集中采购
     */
    public void setPurchaseType(Integer purchaseType) {
        this.purchaseType = purchaseType;
    }

    public String getPurchaseTypeName() {
        return purchaseTypeName;
    }

    public void setPurchaseTypeName(String purchaseTypeName) {
        this.purchaseTypeName = purchaseTypeName;
    }

    /**
     * 计价方式：1-采购；2-租赁
     */
    public Integer getPricingType() {
        return pricingType;
    }

    /**
     * 计价方式：1-采购；2-租赁
     */
    public void setPricingType(Integer pricingType) {
        this.pricingType = pricingType;
    }

    public Integer getPricingTypeName() {
        return pricingTypeName;
    }

    public void setPricingTypeName(Integer pricingTypeName) {
        this.pricingTypeName = pricingTypeName;
    }

    /**
     * 报价权限：1-指定供应商；2-所有供应商
     */
    public Integer getQuotationAuthority() {
        return quotationAuthority;
    }

    /**
     * 报价权限：1-指定供应商；2-所有供应商
     */
    public void setQuotationAuthority(Integer quotationAuthority) {
        this.quotationAuthority = quotationAuthority;
    }

    public Integer getQuotationAuthorityName() {
        return quotationAuthorityName;
    }

    public void setQuotationAuthorityName(Integer quotationAuthorityName) {
        this.quotationAuthorityName = quotationAuthorityName;
    }

    /**
     * 查看权限：1-指定供应商：2-所有供应商登录后查看；3-所有供应商免登录查看
     */
    public Integer getViewAuthority() {
        return viewAuthority;
    }

    /**
     * 查看权限：1-指定供应商：2-所有供应商登录后查看；3-所有供应商免登录查看
     */
    public void setViewAuthority(Integer viewAuthority) {
        this.viewAuthority = viewAuthority;
    }

    public Integer getViewAuthorityName() {
        return viewAuthorityName;
    }

    public void setViewAuthorityName(Integer viewAuthorityName) {
        this.viewAuthorityName = viewAuthorityName;
    }

    /**
     * 询价金额
     */
    public BigDecimal getInquiryMny() {
        return inquiryMny;
    }

    /**
     * 询价金额
     */
    public void setInquiryMny(BigDecimal inquiryMny) {
        this.inquiryMny = inquiryMny;
    }

    /**
     * 计划使用日期
     */
    public Date getPlanUseDate() {
        return planUseDate;
    }

    /**
     * 计划使用日期
     */
    public void setPlanUseDate(Date planUseDate) {
        this.planUseDate = planUseDate;
    }

    /**
     * 经办人id
     */
    @ReferSerialTransfer(referCode = "idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 经办人id
     */
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    /**
     * 经办人
     */
    public String getEmployeeName() {
        return employeeName;
    }

    /**
     * 经办人
     */
    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    /**
     * 经办人部门id
     */
    public Long getDepartmentId() {
        return departmentId;
    }

    /**
     * 经办人部门id
     */
    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }

    /**
     * 经办人部门
     */
    public String getDepartmentName() {
        return departmentName;
    }

    /**
     * 经办人部门
     */
    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }

    /**
     * 询价日期
     */
    public Date getInquiryDate() {
        return inquiryDate;
    }

    /**
     * 询价日期
     */
    public void setInquiryDate(Date inquiryDate) {
        this.inquiryDate = inquiryDate;
    }

    /**
     * 联系人
     */
    public Long getContactsId() {
        return contactsId;
    }

    /**
     * 联系人
     */
    public void setContactsId(Long contactsId) {
        this.contactsId = contactsId;
    }

    /**
     * 联系人姓名
     */
    public String getContactsName() {
        return contactsName;
    }

    /**
     * 联系人姓名
     */
    public void setContactsName(String contactsName) {
        this.contactsName = contactsName;
    }

    /**
     * 联系电话
     */
    public String getPhone() {
        return phone;
    }

    /**
     * 联系电话
     */
    public void setPhone(String phone) {
        this.phone = phone;
    }

    /**
     * 报价截止日期
     */
    public Date getQuoteEndDate() {
        return quoteEndDate;
    }

    /**
     * 报价截止日期
     */
    public void setQuoteEndDate(Date quoteEndDate) {
        this.quoteEndDate = quoteEndDate;
    }

    /**
     * 发票要求
     */
    public String getInvoiceRequirement() {
        return invoiceRequirement;
    }

    /**
     * 发票要求
     */
    public void setInvoiceRequirement(String invoiceRequirement) {
        this.invoiceRequirement = invoiceRequirement;
    }

    /**
     * 付款方式
     */
    public String getPaymentMethod() {
        return paymentMethod;
    }

    /**
     * 付款方式
     */
    public void setPaymentMethod(String paymentMethod) {
        this.paymentMethod = paymentMethod;
    }

    /**
     * 询价说明
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 询价说明
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }

    /**
     * 询价状态：1-未开始；2-报价中；3-已截止；4-已中标
     */
    public Integer getInquiryState() {
        return inquiryState;
    }

    /**
     * 询价状态：1-未开始；2-报价中；3-已截止；4-已中标
     */
    public void setInquiryState(Integer inquiryState) {
        this.inquiryState = inquiryState;
    }

    public String getInquiryStateName() {
        return inquiryStateName;
    }

    public void setInquiryStateName(String inquiryStateName) {
        this.inquiryStateName = inquiryStateName;
    }

    /**
     * 材料询价-采购清单
     */
    public List<MaterialInquiryPurchaseDetailVO> getMaterialInquiryPurchaseDetailList() {
        return materialInquiryPurchaseDetailList;
    }

    /**
     * 材料询价-采购清单
     */
    public void setMaterialInquiryPurchaseDetailList(List<MaterialInquiryPurchaseDetailVO> materialInquiryPurchaseDetailList) {
        this.materialInquiryPurchaseDetailList = materialInquiryPurchaseDetailList;
    }

    /**
     * 材料询价-租赁清单
     */
    public List<MaterialInquiryRentDetailVO> getMaterialInquiryRentDetailList() {
        return materialInquiryRentDetailList;
    }

    /**
     * 材料询价-租赁清单
     */
    public void setMaterialInquiryRentDetailList(List<MaterialInquiryRentDetailVO> materialInquiryRentDetailList) {
        this.materialInquiryRentDetailList = materialInquiryRentDetailList;
    }

    /**
     * 材料询价-候选供应商
     */
    public List<MaterialInquirySupplierVO> getMaterialInquirySupplierList() {
        return materialInquirySupplierList;
    }

    /**
     * 材料询价-候选供应商
     */
    public void setMaterialInquirySupplierList(List<MaterialInquirySupplierVO> materialInquirySupplierList) {
        this.materialInquirySupplierList = materialInquirySupplierList;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }
}

==> ejc-bidprice-api-3.0.0-20230217.055634-63-sources.jar: com/ejianc/business/bidprice/common/vo/InquiryCommonVO.java <==
package com.ejianc.business.bidprice.common.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.business.bidprice.material.vo.MaterialInquiryPurchaseDetailVO;
import com.ejianc.business.bidprice.material.vo.MaterialInquiryRentDetailVO;
import com.ejianc.business.bidprice.material.vo.MaterialInquirySupplierVO;
import com.ejianc.business.bidprice.material.vo.MaterialQuoteVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 材料询价
 *
 * @author generator
 *
 */
@ApiModel("询价公共VO")
public class InquiryCommonVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Integer billState; // 单据状态
    private String billCode; // 单据编码
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private Long orgId; // 组织id
    private String orgName; // 组织id
    private Long parentOrgId; // 项目部所属组织id
    private String parentOrgName; // 项目部所属组织
    private String purchaseSubject; // 采购主题
    private Integer purchaseType; // 采购方式：1-项目自采；2-集中采购
    private String purchaseTypeName; // 采购方式名称
    private Integer pricingType; // 计价方式：1-采购；2-租赁
    private String pricingTypeName; // 计价方式名称
    private Integer quotationAuthority; // 报价权限：1-指定供应商；2-所有供应商
    private String quotationAuthorityName; // 报价权限名称
    private Integer viewAuthority; // 查看权限：1-指定供应商：2-所有供应商登录后查看；3-所有供应商免登录查看
    private String viewAuthorityName; // 查看权限名称
    private BigDecimal inquiryMny; // 询价金额
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date planUseDate; // 计划使用日期
    private Long employeeId; // 经办人id
    private String employeeName; // 经办人
    private Long departmentId; // 经办人部门id
    private String departmentName; // 经办人部门
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date inquiryDate; // 询价日期
    private Long contactsId; // 联系人
    private String contactsName; // 联系人姓名
    private String phone; // 联系电话
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm", timezone = "GMT+8")
    private Date quoteEndDate; // 报价截止日期
    private String invoiceRequirement; // 发票要求
    private String paymentMethod; // 付款方式
    private String memo; // 询价说明
    private Integer inquiryState; // 询价状态：1-未开始；2-报价中；3-已截止；4-已中标

    @ApiModelProperty("材料询价-采购清单")
    private List<MaterialInquiryPurchaseDetailVO> materialInquiryPurchaseDetailList = new ArrayList<>();
    @ApiModelProperty("材料询价-租赁清单")
    private List<MaterialInquiryRentDetailVO> materialInquiryRentDetailList = new ArrayList<>();
    @ApiModelProperty("材料询价-候选供应商")
    private List<MaterialQuoteVO> materialQuoteVOList = new ArrayList<>();

    private BigDecimal sumBidMny; // 中标金额


    public BigDecimal getSumBidMny() {
        return sumBidMny;
    }

    public void setSumBidMny(BigDecimal sumBidMny) {
        this.sumBidMny = sumBidMny;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public String getPurchaseSubject() {
        return purchaseSubject;
    }

    public void setPurchaseSubject(String purchaseSubject) {
        this.purchaseSubject = purchaseSubject;
    }

    public Integer getPurchaseType() {
        return purchaseType;
    }

    public void setPurchaseType(Integer purchaseType) {
        this.purchaseType = purchaseType;
    }

    public String getPurchaseTypeName() {
        return purchaseTypeName;
    }

    public void setPurchaseTypeName(String purchaseTypeName) {
        this.purchaseTypeName = purchaseTypeName;
    }

    public Integer getPricingType() {
        return pricingType;
    }

    public void setPricingType(Integer pricingType) {
        this.pricingType = pricingType;
    }

    public String getPricingTypeName() {
        return pricingTypeName;
    }

    public void setPricingTypeName(String pricingTypeName) {
        this.pricingTypeName = pricingTypeName;
    }

    public Integer getQuotationAuthority() {
        return quotationAuthority;
    }

    public void setQuotationAuthority(Integer quotationAuthority) {
        this.quotationAuthority = quotationAuthority;
    }

    public String getQuotationAuthorityName() {
        return quotationAuthorityName;
    }

    public void setQuotationAuthorityName(String quotationAuthorityName) {
        this.quotationAuthorityName = quotationAuthorityName;
    }

    public Integer getViewAuthority() {
        return viewAuthority;
    }

    public void setViewAuthority(Integer viewAuthority) {
        this.viewAuthority = viewAuthority;
    }

    public String getViewAuthorityName() {
        return viewAuthorityName;
    }

    public void setViewAuthorityName(String viewAuthorityName) {
        this.viewAuthorityName = viewAuthorityName;
    }

    public BigDecimal getInquiryMny() {
        return inquiryMny;
    }

    public void setInquiryMny(BigDecimal inquiryMny) {
        this.inquiryMny = inquiryMny;
    }

    public Date getPlanUseDate() {
        return planUseDate;
    }

    public void setPlanUseDate(Date planUseDate) {
        this.planUseDate = planUseDate;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }

    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }

    public Date getInquiryDate() {
        return inquiryDate;
    }

    public void setInquiryDate(Date inquiryDate) {
        this.inquiryDate = inquiryDate;
    }

    public Long getContactsId() {
        return contactsId;
    }

    public void setContactsId(Long contactsId) {
        this.contactsId = contactsId;
    }

    public String getContactsName() {
        return contactsName;
    }

    public void setContactsName(String contactsName) {
        this.contactsName = contactsName;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public Date getQuoteEndDate() {
        return quoteEndDate;
    }

    public void setQuoteEndDate(Date quoteEndDate) {
        this.quoteEndDate = quoteEndDate;
    }

    public String getInvoiceRequirement() {
        return invoiceRequirement;
    }

    public void setInvoiceRequirement(String invoiceRequirement) {
        this.invoiceRequirement = invoiceRequirement;
    }

    public String getPaymentMethod() {
        return paymentMethod;
    }

    public void setPaymentMethod(String paymentMethod) {
        this.paymentMethod = paymentMethod;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Integer getInquiryState() {
        return inquiryState;
    }

    public void setInquiryState(Integer inquiryState) {
        this.inquiryState = inquiryState;
    }

    public List<MaterialInquiryPurchaseDetailVO> getMaterialInquiryPurchaseDetailList() {
        return materialInquiryPurchaseDetailList;
    }

    public void setMaterialInquiryPurchaseDetailList(List<MaterialInquiryPurchaseDetailVO> materialInquiryPurchaseDetailList) {
        this.materialInquiryPurchaseDetailList = materialInquiryPurchaseDetailList;
    }

    public List<MaterialInquiryRentDetailVO> getMaterialInquiryRentDetailList() {
        return materialInquiryRentDetailList;
    }

    public void setMaterialInquiryRentDetailList(List<MaterialInquiryRentDetailVO> materialInquiryRentDetailList) {
        this.materialInquiryRentDetailList = materialInquiryRentDetailList;
    }

    public List<MaterialQuoteVO> getMaterialQuoteVOList() {
        return materialQuoteVOList;
    }

    public void setMaterialQuoteVOList(List<MaterialQuoteVO> materialQuoteVOList) {
        this.materialQuoteVOList = materialQuoteVOList;
    }
}
